[nautilus-actions/file-manager-actions] FMAStatusbar class is renamed to FMAStatusBar



commit a07166d2451a164d6329be6c43e0def9853c9657
Author: Pierre Wieser <pwieser trychlos org>
Date:   Tue Sep 8 20:36:19 2015 +0200

    FMAStatusbar class is renamed to FMAStatusBar

 src/ui/Makefile.am                           |    4 +-
 src/ui/fma-iaction-tab.c                     |    8 +-
 src/ui/fma-icommand-tab.c                    |    2 +-
 src/ui/fma-main-window.c                     |   18 +++---
 src/ui/fma-main-window.h                     |    4 +-
 src/ui/fma-menu-file.c                       |    8 +-
 src/ui/fma-menu.c                            |    4 +-
 src/ui/{fma-statusbar.c => fma-status-bar.c} |   98 +++++++++++++-------------
 src/ui/{fma-statusbar.h => fma-status-bar.h} |   44 ++++++------
 src/ui/nact-tree-model-dnd.c                 |   28 ++++----
 10 files changed, 109 insertions(+), 109 deletions(-)
---
diff --git a/src/ui/Makefile.am b/src/ui/Makefile.am
index cd48d8b..a2c2baa 100644
--- a/src/ui/Makefile.am
+++ b/src/ui/Makefile.am
@@ -130,8 +130,8 @@ fma_config_tool_SOURCES = \
        fma-schemes-list.h                                                                      \
        fma-sort-buttons.c                                                                      \
        fma-sort-buttons.h                                                                      \
-       fma-statusbar.c                                                                 \
-       fma-statusbar.h                                                                 \
+       fma-status-bar.c                                                                        \
+       fma-status-bar.h                                                                        \
        fma-tree-ieditable.c                                                            \
        fma-tree-ieditable.h                                                            \
        nact-tree-model.c                                                                       \
diff --git a/src/ui/fma-iaction-tab.c b/src/ui/fma-iaction-tab.c
index fabc872..44fdd8b 100644
--- a/src/ui/fma-iaction-tab.c
+++ b/src/ui/fma-iaction-tab.c
@@ -41,7 +41,7 @@
 #include "core/fma-io-provider.h"
 
 #include "fma-application.h"
-#include "fma-statusbar.h"
+#include "fma-status-bar.h"
 #include "base-gtk-utils.h"
 #include "fma-main-tab.h"
 #include "fma-main-window.h"
@@ -542,13 +542,13 @@ static void
 check_for_label( FMAIActionTab *instance, GtkEntry *entry, const gchar *label )
 {
        FMAObjectItem *item;
-       FMAStatusbar *bar;
+       FMAStatusBar *bar;
 
        g_return_if_fail( FMA_IS_IACTION_TAB( instance ));
        g_return_if_fail( GTK_IS_ENTRY( entry ));
 
        bar = fma_main_window_get_statusbar( FMA_MAIN_WINDOW( instance ));
-       fma_statusbar_hide_status( bar, IACTION_TAB_CONTEXT );
+       fma_status_bar_hide_status( bar, IACTION_TAB_CONTEXT );
        set_label_label( instance, "black" );
 
        g_object_get( G_OBJECT( instance ), MAIN_PROP_ITEM, &item, NULL );
@@ -556,7 +556,7 @@ check_for_label( FMAIActionTab *instance, GtkEntry *entry, const gchar *label )
        if( item && g_utf8_strlen( label, -1 ) == 0 ){
 
                /* i18n: status bar message when the action label is empty */
-               fma_statusbar_display_status(
+               fma_status_bar_display_status(
                                bar,
                                IACTION_TAB_CONTEXT,
                                _( "Caution: a label is mandatory for the action or the menu." ));
diff --git a/src/ui/fma-icommand-tab.c b/src/ui/fma-icommand-tab.c
index df08148..44a8efd 100644
--- a/src/ui/fma-icommand-tab.c
+++ b/src/ui/fma-icommand-tab.c
@@ -42,7 +42,7 @@
 #include "core/fma-tokens.h"
 
 #include "fma-application.h"
-#include "fma-statusbar.h"
+#include "fma-status-bar.h"
 #include "base-gtk-utils.h"
 #include "fma-main-tab.h"
 #include "fma-main-window.h"
diff --git a/src/ui/fma-main-window.h b/src/ui/fma-main-window.h
index 3fa34fe..81ef83d 100644
--- a/src/ui/fma-main-window.h
+++ b/src/ui/fma-main-window.h
@@ -41,7 +41,7 @@
 #include "fma-clipboard.h"
 #include "fma-main-window-def.h"
 #include "fma-sort-buttons.h"
-#include "fma-statusbar.h"
+#include "fma-status-bar.h"
 #include "nact-tree-view.h"
 
 G_BEGIN_DECLS
@@ -77,7 +77,7 @@ FMAClipboard   *fma_main_window_get_clipboard   ( const FMAMainWindow *window );
 
 FMASortButtons *fma_main_window_get_sort_buttons( const FMAMainWindow *window );
 
-FMAStatusbar   *fma_main_window_get_statusbar   ( const FMAMainWindow *window );
+FMAStatusBar   *fma_main_window_get_statusbar   ( const FMAMainWindow *window );
 
 NactTreeView    *fma_main_window_get_items_view  ( const FMAMainWindow *window );
 
diff --git a/src/ui/fma-menu-file.c b/src/ui/fma-menu-file.c
index 065d0ce..5cb9d68 100644
--- a/src/ui/fma-menu-file.c
+++ b/src/ui/fma-menu-file.c
@@ -41,7 +41,7 @@
 #include <core/fma-iprefs.h>
 
 #include "fma-application.h"
-#include "fma-statusbar.h"
+#include "fma-status-bar.h"
 #include "fma-main-tab.h"
 #include "fma-main-window.h"
 #include "fma-menu.h"
@@ -425,14 +425,14 @@ on_autosave_prefs_timeout( FMAMainWindow *main_window )
 static gboolean
 autosave_callback( FMAMainWindow *main_window )
 {
-       FMAStatusbar *bar;
+       FMAStatusBar *bar;
        const gchar *context = "autosave-context";
        g_debug( "fma_menu_file_autosave_callback" );
 
        bar = fma_main_window_get_statusbar( main_window );
-       fma_statusbar_display_status( bar, context, _( "Automatically saving pending modifications..." ));
+       fma_status_bar_display_status( bar, context, _( "Automatically saving pending modifications..." ));
        fma_menu_file_save_items( main_window );
-       fma_statusbar_hide_status( bar, context );
+       fma_status_bar_hide_status( bar, context );
 
        return( TRUE );
 }
diff --git a/src/ui/fma-menu.c b/src/ui/fma-menu.c
index 15271d2..93f62c7 100644
--- a/src/ui/fma-menu.c
+++ b/src/ui/fma-menu.c
@@ -442,7 +442,7 @@ on_tree_view_count_changed( NactTreeView *treeview, gboolean reset, gint menus,
 {
        static const gchar *thisfn = "fma_menu_on_tree_view_count_changed";
        sMenuData *sdata;
-       FMAStatusbar *bar;
+       FMAStatusBar *bar;
        gchar *status;
 
        g_debug( "%s: treeview=%p, reset=%s, menus=%d, actions=%d, profiles=%d, window=%p",
@@ -470,7 +470,7 @@ on_tree_view_count_changed( NactTreeView *treeview, gboolean reset, gint menus,
                        sdata->count_menus, sdata->count_actions, sdata->count_profiles );
 
        bar = fma_main_window_get_statusbar( window );
-       fma_statusbar_display_status( bar, "menu-status-context", status );
+       fma_status_bar_display_status( bar, "menu-status-context", status );
        g_free( status );
 
        g_signal_emit_by_name( window, MAIN_SIGNAL_UPDATE_SENSITIVITIES );
diff --git a/src/ui/nact-tree-model-dnd.c b/src/ui/nact-tree-model-dnd.c
index a19bfae..953943a 100644
--- a/src/ui/nact-tree-model-dnd.c
+++ b/src/ui/nact-tree-model-dnd.c
@@ -43,7 +43,7 @@
 
 #include "fma-application.h"
 #include "fma-clipboard.h"
-#include "fma-statusbar.h"
+#include "fma-status-bar.h"
 #include "fma-main-window.h"
 #include "nact-tree-model.h"
 #include "nact-tree-model-priv.h"
@@ -668,7 +668,7 @@ is_drop_possible( NactTreeModel *model, GtkTreePath *dest, FMAObjectItem **paren
        FMAMainWindow *main_window;
        GtkTreeIter iter;
        FMAObjectItem *parent_dest;
-       FMAStatusbar *bar;
+       FMAStatusBar *bar;
 
        priv = model->private;
        drop_ok = FALSE;
@@ -692,7 +692,7 @@ is_drop_possible( NactTreeModel *model, GtkTreePath *dest, FMAObjectItem **paren
 
                if( priv->drag_has_profiles ){
                        bar = fma_main_window_get_statusbar( main_window );
-                       fma_statusbar_display_with_timeout(
+                       fma_status_bar_display_with_timeout(
                                                bar, TREE_MODEL_STATUSBAR_CONTEXT, gettext( 
st_refuse_drop_profile ));
 
                } else {
@@ -725,7 +725,7 @@ is_drop_possible_before_iter( NactTreeModel *model, GtkTreeIter *iter, FMAMainWi
        static const gchar *thisfn = "nact_tree_model_dnd_is_drop_possible_before_iter";
        gboolean drop_ok;
        FMAObject *object;
-       FMAStatusbar *bar;
+       FMAStatusBar *bar;
 
        drop_ok = FALSE;
        *parent = NULL;
@@ -743,7 +743,7 @@ is_drop_possible_before_iter( NactTreeModel *model, GtkTreeIter *iter, FMAMainWi
 
                } else {
                        /* unable to drop a profile here */
-                       fma_statusbar_display_with_timeout(
+                       fma_status_bar_display_with_timeout(
                                        bar, TREE_MODEL_STATUSBAR_CONTEXT, gettext( st_refuse_drop_profile ));
                }
 
@@ -753,7 +753,7 @@ is_drop_possible_before_iter( NactTreeModel *model, GtkTreeIter *iter, FMAMainWi
 
        } else {
                /* unable to drop an action or a menu here */
-               fma_statusbar_display_with_timeout(
+               fma_status_bar_display_with_timeout(
                                bar, TREE_MODEL_STATUSBAR_CONTEXT, gettext( st_refuse_drop_item ));
        }
 
@@ -768,7 +768,7 @@ is_drop_possible_into_dest( NactTreeModel *model, GtkTreePath *dest, FMAMainWind
        GtkTreePath *path;
        GtkTreeIter iter;
        FMAObject *object;
-       FMAStatusbar *bar;
+       FMAStatusBar *bar;
 
        drop_ok = FALSE;
        *parent = NULL;
@@ -789,7 +789,7 @@ is_drop_possible_into_dest( NactTreeModel *model, GtkTreePath *dest, FMAMainWind
                                        *parent = FMA_OBJECT_ITEM( object );
 
                                } else {
-                                       fma_statusbar_display_with_timeout(
+                                       fma_status_bar_display_with_timeout(
                                                        bar, TREE_MODEL_STATUSBAR_CONTEXT, gettext( 
st_refuse_drop_profile ));
                                }
 
@@ -798,7 +798,7 @@ is_drop_possible_into_dest( NactTreeModel *model, GtkTreePath *dest, FMAMainWind
                                        *parent = fma_object_get_parent( object );
 
                        } else {
-                               fma_statusbar_display_with_timeout(
+                               fma_status_bar_display_with_timeout(
                                                bar, TREE_MODEL_STATUSBAR_CONTEXT, gettext( 
st_refuse_drop_item ));
                        }
                }
@@ -877,7 +877,7 @@ drop_uri_list( NactTreeModel *model, GtkTreePath *dest, GtkSelectionData  *selec
        GSList *messages;
        gchar *dlg_message;
        GtkWidget *dialog;
-       FMAStatusbar *bar;
+       FMAStatusBar *bar;
 
        priv = model->private;
        gchar *dest_str = gtk_tree_path_to_string( dest );
@@ -942,7 +942,7 @@ drop_uri_list( NactTreeModel *model, GtkTreePath *dest, GtkSelectionData  *selec
        g_debug( "%s: count=%d", thisfn, count );
        if( count == 1 ){
                bar = fma_main_window_get_statusbar( main_window );
-               fma_statusbar_display_with_timeout(
+               fma_status_bar_display_with_timeout(
                                bar, TREE_MODEL_STATUSBAR_CONTEXT, messages->data );
        }
        if( count > 1 ){
@@ -1154,7 +1154,7 @@ is_parent_accept_new_children( FMAApplication *application, FMAMainWindow *windo
 {
        gboolean accept_ok;
        FMAUpdater *updater;
-       FMAStatusbar *bar;
+       FMAStatusBar *bar;
 
        accept_ok = FALSE;
        updater = fma_application_get_updater( application );
@@ -1168,7 +1168,7 @@ is_parent_accept_new_children( FMAApplication *application, FMAMainWindow *windo
                        accept_ok = TRUE;
 
                } else {
-                       fma_statusbar_display_with_timeout(
+                       fma_status_bar_display_with_timeout(
                                                bar, TREE_MODEL_STATUSBAR_CONTEXT, gettext( 
st_level_zero_not_writable ));
                }
 
@@ -1178,7 +1178,7 @@ is_parent_accept_new_children( FMAApplication *application, FMAMainWindow *windo
                accept_ok = TRUE;
 
        } else {
-                       fma_statusbar_display_with_timeout(
+                       fma_status_bar_display_with_timeout(
                                                bar, TREE_MODEL_STATUSBAR_CONTEXT, gettext( 
st_parent_not_writable ));
        }
 


[Date Prev][Date Next]   [Thread Prev][Thread Next]   [Thread Index] [Date Index] [Author Index]
diff --git a/src/ui/fma-main-window.c b/src/ui/fma-main-window.c
index d8dfb3f..d880812 100644
--- a/src/ui/fma-main-window.c
+++ b/src/ui/fma-main-window.c
@@ -55,7 +55,7 @@
 #include "fma-main-tab.h"
 #include "fma-main-window.h"
 #include "fma-menu.h"
-#include "fma-statusbar.h"
+#include "fma-status-bar.h"
 #include "nact-tree-view.h"
 #include "fma-confirm-logout.h"
 #include "fma-sort-buttons.h"
@@ -115,7 +115,7 @@ struct _FMAMainWindowPrivate {
        NactTreeView      *items_view;
        gboolean          is_tree_modified;
        FMAClipboard     *clipboard;
-       FMAStatusbar     *statusbar;
+       FMAStatusBar     *statusbar;
        FMASortButtons   *sort_buttons;
 
        gulong            pivot_handler_id;
@@ -706,7 +706,7 @@ setup_main_ui( FMAMainWindow *main_window )
        GtkWidget *notebook;
        guint pos;
        GtkWidget *pane;
-       FMAStatusbar *bar;
+       FMAStatusBar *bar;
 
        /* no error condition here:
         * If there is an error opening the file or parsing the description
@@ -746,7 +746,7 @@ setup_main_ui( FMAMainWindow *main_window )
 
        /* setup statusbar
         */
-       bar = fma_statusbar_new();
+       bar = fma_status_bar_new();
        alignment = fma_gtk_utils_find_widget_by_name( GTK_CONTAINER( top_widget ), "main-statusbar" );
        g_return_if_fail( alignment && GTK_IS_CONTAINER( alignment ));
        gtk_container_add( GTK_CONTAINER( alignment ), GTK_WIDGET( bar ));
@@ -858,12 +858,12 @@ fma_main_window_get_sort_buttons( const FMAMainWindow *window )
  * fma_main_window_get_statusbar:
  * @window: this #FMAMainWindow instance.
  *
  * Returns: the #FMAStatusbar object.
  */
-FMAStatusbar *
+FMAStatusBar *
 fma_main_window_get_statusbar( const FMAMainWindow *window )
 {
-       FMAStatusbar *bar;
+       FMAStatusBar *bar;
 
        g_return_val_if_fail( window && FMA_IS_MAIN_WINDOW( window ), NULL );
 
@@ -1030,7 +1030,7 @@ raz_selection_properties( FMAMainWindow *window )
        window->private->editable = FALSE;
        window->private->reason = 0;
 
-       fma_statusbar_set_locked( window->private->statusbar, FALSE, 0 );
+       fma_status_bar_set_locked( window->private->statusbar, FALSE, 0 );
 }
 
 /*
@@ -1108,7 +1108,7 @@ setup_writability_status( FMAMainWindow *window )
        g_return_if_fail( FMA_IS_OBJECT_ITEM( window->private->current_item ));
 
        window->private->editable = fma_object_is_finally_writable( window->private->current_item, 
&window->private->reason );
-       fma_statusbar_set_locked( window->private->statusbar, !window->private->editable, 
window->private->reason );
+       fma_status_bar_set_locked( window->private->statusbar, !window->private->editable, 
window->private->reason );
 }
 
@@ -858,12 +858,12 @@ fma_main_window_get_sort_buttons( const FMAMainWindow *window )
  * @window: this #FMAMainWindow instance.
  *
- * Returns: the #FMAStatusbar object.
+ * Returns: the #FMAStatusBar object.
  */
 /*
diff --git a/src/ui/fma-statusbar.c b/src/ui/fma-status-bar.c
similarity index 74%
rename from src/ui/fma-statusbar.c
rename to src/ui/fma-status-bar.c
index 5985743..c21dbd2 100644
--- a/src/ui/fma-statusbar.c
+++ b/src/ui/fma-status-bar.c
@@ -35,9 +35,9 @@
 #include "core/fma-io-provider.h"
 
 #include "base-gtk-utils.h"
-#include "fma-statusbar.h"
+#include "fma-status-bar.h"
 
-struct _FMAStatusbarPrivate {
+struct _FMAStatusBarPrivate {
        gboolean   dispose_has_run;
        GtkWidget *image;
 };
@@ -45,7 +45,7 @@ struct _FMAStatusbarPrivate {
 typedef struct {
        guint         event_source_id;
        guint         context_id;
-       FMAStatusbar *bar;
+       FMAStatusBar *bar;
 }
        StatusbarTimeoutDisplayStruct;
 
@@ -54,16 +54,16 @@ typedef struct {
 static GObjectClass *st_parent_class    = NULL;
 
 static GType    register_type( void );
-static void     class_init( FMAStatusbarClass *klass );
+static void     class_init( FMAStatusBarClass *klass );
 static void     instance_init( GTypeInstance *instance, gpointer klass );
 static void     instance_dispose( GObject *application );
 static void     instance_finalize( GObject *application );
-static void     init_bar( FMAStatusbar *bar );
+static void     init_bar( FMAStatusBar *bar );
 static gboolean display_timeout( StatusbarTimeoutDisplayStruct *stds );
 static void     display_timeout_free( StatusbarTimeoutDisplayStruct *stds );
 
 GType
-fma_statusbar_get_type( void )
+fma_status_bar_get_type( void )
 {
        static GType type = 0;
 
@@ -77,32 +77,32 @@ fma_statusbar_get_type( void )
 static GType
 register_type( void )
 {
-       static const gchar *thisfn = "fma_statusbar_register_type";
+       static const gchar *thisfn = "fma_status_bar_register_type";
        GType type;
 
        static GTypeInfo info = {
-               sizeof( FMAStatusbarClass ),
+               sizeof( FMAStatusBarClass ),
                ( GBaseInitFunc ) NULL,
                ( GBaseFinalizeFunc ) NULL,
                ( GClassInitFunc ) class_init,
                NULL,
                NULL,
-               sizeof( FMAStatusbar ),
+               sizeof( FMAStatusBar ),
                0,
                ( GInstanceInitFunc ) instance_init
        };
 
        g_debug( "%s", thisfn );
 
-       type = g_type_register_static( GTK_TYPE_STATUSBAR, "FMAStatusbar", &info, 0 );
+       type = g_type_register_static( GTK_TYPE_STATUSBAR, "FMAStatusBar", &info, 0 );
 
        return( type );
 }
 
 static void
-class_init( FMAStatusbarClass *klass )
+class_init( FMAStatusBarClass *klass )
 {
-       static const gchar *thisfn = "fma_statusbar_class_init";
+       static const gchar *thisfn = "fma_status_bar_class_init";
        GObjectClass *object_class;
 
        g_debug( "%s: klass=%p", thisfn, ( void * ) klass );
@@ -117,17 +117,17 @@ class_init( FMAStatusbarClass *klass )
 static void
 instance_init( GTypeInstance *instance, gpointer klass )
 {
-       static const gchar *thisfn = "fma_statusbar_instance_init";
-       FMAStatusbar *self;
+       static const gchar *thisfn = "fma_status_bar_instance_init";
+       FMAStatusBar *self;
 
-       g_return_if_fail( FMA_IS_STATUSBAR( instance ));
+       g_return_if_fail( FMA_IS_STATUS_BAR( instance ));
 
        g_debug( "%s: instance=%p (%s), klass=%p",
                        thisfn, ( void * ) instance, G_OBJECT_TYPE_NAME( instance ), ( void * ) klass );
 
-       self = FMA_STATUSBAR( instance );
+       self = FMA_STATUS_BAR( instance );
 
-       self->private = g_new0( FMAStatusbarPrivate, 1 );
+       self->private = g_new0( FMAStatusBarPrivate, 1 );
 
        self->private->dispose_has_run = FALSE;
 }
@@ -135,12 +135,12 @@ instance_init( GTypeInstance *instance, gpointer klass )
 static void
 instance_dispose( GObject *object )
 {
-       static const gchar *thisfn = "fma_statusbar_instance_dispose";
-       FMAStatusbarPrivate *priv;
+       static const gchar *thisfn = "fma_status_bar_instance_dispose";
+       FMAStatusBarPrivate *priv;
 
-       g_return_if_fail( FMA_IS_STATUSBAR( object ));
+       g_return_if_fail( FMA_IS_STATUS_BAR( object ));
 
-       priv = FMA_STATUSBAR( object )->private;
+       priv = FMA_STATUS_BAR( object )->private;
 
        if( !priv->dispose_has_run ){
 
@@ -159,14 +159,14 @@ instance_dispose( GObject *object )
 static void
 instance_finalize( GObject *instance )
 {
-       static const gchar *thisfn = "fma_statusbar_instance_finalize";
-       FMAStatusbar *self;
+       static const gchar *thisfn = "fma_status_bar_instance_finalize";
+       FMAStatusBar *self;
 
-       g_return_if_fail( FMA_IS_STATUSBAR( instance ));
+       g_return_if_fail( FMA_IS_STATUS_BAR( instance ));
 
        g_debug( "%s: instance=%p (%s)", thisfn, ( void * ) instance, G_OBJECT_TYPE_NAME( instance ));
 
-       self = FMA_STATUSBAR( instance );
+       self = FMA_STATUS_BAR( instance );
 
        g_free( self->private );
 
@@ -177,16 +177,16 @@ instance_finalize( GObject *instance )
 }
 
 /**
- * fma_statusbar_new:
+ * fma_status_bar_new:
  *
  * Returns: a new #FMAStatusbar object.
  */
-FMAStatusbar *
-fma_statusbar_new( void )
+FMAStatusBar *
+fma_status_bar_new( void )
 {
-       FMAStatusbar *bar;
+       FMAStatusBar *bar;
 
-       bar = g_object_new( FMA_TYPE_STATUSBAR, NULL );
+       bar = g_object_new( FMA_TYPE_STATUS_BAR, NULL );
 
        init_bar( bar );
 
@@ -194,7 +194,7 @@ fma_statusbar_new( void )
 }
 
 static void
-init_bar( FMAStatusbar *bar )
+init_bar( FMAStatusBar *bar )
 {
        GtkWidget *frame, *image;
 
@@ -207,17 +207,17 @@ init_bar( FMAStatusbar *bar )
 }
 
 /**
- * fma_statusbar_display_status:
- * @bar: this #FMAStatusbar instance.
+ * fma_status_bar_display_status:
+ * @bar: this #FMAStatusBar instance.
  * @context: the context to be displayed.
  * @status: the message.
  *
  * Push a message.
  */
 void
-fma_statusbar_display_status( FMAStatusbar *bar, const gchar *context, const gchar *status )
+fma_status_bar_display_status( FMAStatusBar *bar, const gchar *context, const gchar *status )
 {
-       static const gchar *thisfn = "fma_statusbar_display_status";
+       static const gchar *thisfn = "fma_status_bar_display_status";
 
        g_debug( "%s: bar=%p, context=%s, status=%s",
                        thisfn, ( void * ) bar, context, status );
@@ -231,8 +231,8 @@ fma_statusbar_display_status( FMAStatusbar *bar, const gchar *context, const gch
 }
 
 /**
- * fma_statusbar_display_with_timeout:
- * @bar: this #FMAStatusbar instance.
+ * fma_status_bar_display_with_timeout:
+ * @bar: this #FMAStatusBar instance.
  * @context: the context to be displayed.
  * @status: the message.
  *
@@ -242,9 +242,9 @@ fma_statusbar_display_status( FMAStatusbar *bar, const gchar *context, const gch
  * previous one.
  */
 void
-fma_statusbar_display_with_timeout( FMAStatusbar *bar, const gchar *context, const gchar *status )
+fma_status_bar_display_with_timeout( FMAStatusBar *bar, const gchar *context, const gchar *status )
 {
-       static const gchar *thisfn = "fma_statusbar_display_with_timeout";
+       static const gchar *thisfn = "fma_status_bar_display_with_timeout";
        StatusbarTimeoutDisplayStruct *stds;
 
        g_debug( "%s: bar=%p, context=%s, status=%s",
@@ -269,22 +269,22 @@ fma_statusbar_display_with_timeout( FMAStatusbar *bar, const gchar *context, con
 }
 
 /**
- * fma_statusbar_hide_status:
- * @bar: this #FMAStatusbar instance.
+ * fma_status_bar_hide_status:
+ * @bar: this #FMAStatusBar instance.
  * @context: the context to be hidden.
  *
  * Hide the specified context.
  */
 void
-fma_statusbar_hide_status( FMAStatusbar *bar, const gchar *context )
+fma_status_bar_hide_status( FMAStatusBar *bar, const gchar *context )
 {
        guint context_id = gtk_statusbar_get_context_id( GTK_STATUSBAR( bar ), context );
        gtk_statusbar_pop( GTK_STATUSBAR( bar ), context_id );
 }
 
 /**
- * fma_statusbar_set_locked:
- * @bar: this #FMAStatusbar instance.
+ * fma_status_bar_set_locked:
+ * @bar: this #FMAStatusBar instance.
  * @provider: whether the current provider is locked (read-only).
  * @item: whether the current item is locked (read-only).
  *
@@ -292,10 +292,10 @@ fma_statusbar_hide_status( FMAStatusbar *bar, const gchar *context )
  * Installs the corresponding tooltip.
  */
 void
-fma_statusbar_set_locked( FMAStatusbar *bar, gboolean readonly, gint reason )
+fma_status_bar_set_locked( FMAStatusBar *bar, gboolean readonly, gint reason )
 {
-       static const gchar *thisfn = "fma_statusbar_set_locked";
-       FMAStatusbarPrivate *priv;
+       static const gchar *thisfn = "fma_status_bar_set_locked";
+       FMAStatusBarPrivate *priv;
        gchar *tooltip;
        gboolean set_pixbuf;
 
@@ -337,7 +337,7 @@ display_timeout( StatusbarTimeoutDisplayStruct *stds )
 static void
 display_timeout_free( StatusbarTimeoutDisplayStruct *stds )
 {
-       g_debug( "fma_statusbar_display_timeout_free: stds=%p", ( void * ) stds );
+       g_debug( "fma_status_bar_display_timeout_free: stds=%p", ( void * ) stds );
 
        g_free( stds );
 }
@@ -177,16 +177,16 @@ instance_finalize( GObject *instance )
  *
- * Returns: a new #FMAStatusbar object.
+ * Returns: a new #FMAStatusBar object.
  */
diff --git a/src/ui/fma-statusbar.h b/src/ui/fma-status-bar.h
similarity index 55%
rename from src/ui/fma-statusbar.h
rename to src/ui/fma-status-bar.h
index d3f7473..d77b05b 100644
--- a/src/ui/fma-statusbar.h
+++ b/src/ui/fma-status-bar.h
@@ -27,15 +27,15 @@
  *   ... and many others (see AUTHORS)
  */
 
-#ifndef __UI_FMA_STATUSBAR_H__
-#define __UI_FMA_STATUSBAR_H__
+#ifndef __UI_FMA_STATUS_BAR_H__
+#define __UI_FMA_STATUS_BAR_H__
 
 /**
- * SECTION: fma_statusbar
+ * SECTION: fma_status_bar
  * @short_description: Statusbar class definition.
- * @include: ui/fma-statusbar.h
+ * @include: ui/fma-status-bar.h
  *
  * The #FMAStatusbar embeds both:
  * - a message bar
  * - a read-only indicator.
  */
@@ -44,47 +44,47 @@
 
 G_BEGIN_DECLS
 
-#define FMA_TYPE_STATUSBAR                ( fma_statusbar_get_type())
-#define FMA_STATUSBAR( object )           ( G_TYPE_CHECK_INSTANCE_CAST( object, FMA_TYPE_STATUSBAR, 
FMAStatusbar ))
-#define FMA_STATUSBAR_CLASS( klass )      ( G_TYPE_CHECK_CLASS_CAST( klass, FMA_TYPE_STATUSBAR, 
FMAStatusbarClass ))
-#define FMA_IS_STATUSBAR( object )        ( G_TYPE_CHECK_INSTANCE_TYPE( object, FMA_TYPE_STATUSBAR ))
-#define FMA_IS_STATUSBAR_CLASS( klass )   ( G_TYPE_CHECK_CLASS_TYPE(( klass ), FMA_TYPE_STATUSBAR ))
-#define FMA_STATUSBAR_GET_CLASS( object ) ( G_TYPE_INSTANCE_GET_CLASS(( object ), FMA_TYPE_STATUSBAR, 
FMAStatusbarClass ))
+#define FMA_TYPE_STATUS_BAR                ( fma_status_bar_get_type())
+#define FMA_STATUS_BAR( object )           ( G_TYPE_CHECK_INSTANCE_CAST( object, FMA_TYPE_STATUS_BAR, 
FMAStatusBar ))
+#define FMA_STATUS_BAR_CLASS( klass )      ( G_TYPE_CHECK_CLASS_CAST( klass, FMA_TYPE_STATUS_BAR, 
FMAStatusBarClass ))
+#define FMA_IS_STATUS_BAR( object )        ( G_TYPE_CHECK_INSTANCE_TYPE( object, FMA_TYPE_STATUS_BAR ))
+#define FMA_IS_STATUS_BAR_CLASS( klass )   ( G_TYPE_CHECK_CLASS_TYPE(( klass ), FMA_TYPE_STATUS_BAR ))
+#define FMA_STATUS_BAR_GET_CLASS( object ) ( G_TYPE_INSTANCE_GET_CLASS(( object ), FMA_TYPE_STATUS_BAR, 
FMAStatusBarClass ))
 
-typedef struct _FMAStatusbarPrivate       FMAStatusbarPrivate;
+typedef struct _FMAStatusBarPrivate        FMAStatusBarPrivate;
 
 typedef struct {
        /*< private >*/
        GtkStatusbar         parent;
-       FMAStatusbarPrivate *private;
+       FMAStatusBarPrivate *private;
 }
-       FMAStatusbar;
+       FMAStatusBar;
 
 typedef struct {
        /*< private >*/
        GtkStatusbarClass    parent;
 }
-       FMAStatusbarClass;
+       FMAStatusBarClass;
 
-GType         fma_statusbar_get_type            ( void );
+GType         fma_status_bar_get_type            ( void );
 
-FMAStatusbar *fma_statusbar_new                 ( void );
+FMAStatusBar *fma_status_bar_new                 ( void );
 
-void          fma_statusbar_display_status      ( FMAStatusbar *bar,
+void          fma_status_bar_display_status      ( FMAStatusBar *bar,
                                                                                                              
  const gchar *context,
                                                                                                              
  const gchar *status );
 
-void          fma_statusbar_display_with_timeout( FMAStatusbar *bar,
+void          fma_status_bar_display_with_timeout( FMAStatusBar *bar,
                                                                                                              
  const gchar *context,
                                                                                                              
  const gchar *status );
 
-void          fma_statusbar_hide_status         ( FMAStatusbar *bar,
+void          fma_status_bar_hide_status         ( FMAStatusBar *bar,
                                                                                                              
  const gchar *context );
 
-void          fma_statusbar_set_locked          ( FMAStatusbar *bar,
+void          fma_status_bar_set_locked          ( FMAStatusBar *bar,
                                                                                                              
  gboolean readonly,
                                                                                                              
  gint reason );
 
 G_END_DECLS
 
-#endif /* __UI_FMA_STATUSBAR_H__ */
+#endif /* __UI_FMA_STATUS_BAR_H__ */
@@ -27,15 +27,15 @@
  *
- * The #FMAStatusbar embeds both:
+ * The #FMAStatusBar embeds both:
  * - a message bar
  * - a read-only indicator.